@@ -1,6 +1,6 @@
 package OpenInteract::Page::Database;
 
-# $Id: Database.pm,v 1.5 2001/11/27 12:09:36 lachoy Exp $
+# $Id: Database.pm,v 1.6 2002/01/30 17:50:13 lachoy Exp $
 
 use strict;
 
@@ -40,6 +40,11 @@ sub save {
 }
 
 
+# This is a no-op for us, since the location will have been renamed
+# properly in the upgrade
+
+sub rename { return 1 }
+
 sub remove {
     my ( $class, $page ) = @_;
     my $page_content = eval { $page->page_content };
